Generate Hi-C matrices — FAN-C 0.9.1-beta documentation

# Generate Hi-C matrices

- fanc auto: Automated generation of Hi-C matrices
  - Parameters
  - Input types
  - Test runs and Sun/Oracle/Slurm Grid engine support
  - Next steps
- Individual pipeline steps
  - fanc map: Mapping FASTQ files
  - fanc pairs: Generating and filtering read Pairs
  - fanc hic: Generating, binning, and filtering Hic objects
- Helper tools
  - fanc from-txt: import Hic from text file
  - fanc dump: export Hic objects to text file
  - fanc subset: create Hic objects by subsetting
  - fanc downsample: downsample Hic objects
  - fanc fragments: in silico genome digestion
  - fanc sort-sam: sort SAM files by name
- Configuration options